@@ -1,16 +1,16 @@
 #!/bin/sh
 #
 # autogen.sh glue for pxlib
-# $Id: autogen.sh,v 1.10 2015/12/27 06:52:34 steinm Exp $
+# $Id$
 #
 # Requires: automake, autoconf, dpkg-dev
 set -e
 
 # Refresh GNU autotools toolchain.
 for i in config.guess config.sub missing install-sh mkinstalldirs ; do
-	test -r /usr/share/automake/${i} && {
+	test -r /usr/share/automake-1.16/${i} && {
 		rm -f ${i}
-		cp /usr/share/automake/${i} .
+		cp /usr/share/automake-1.16/${i} .
 	}
 	chmod 755 ${i}
 done
