@@ -1,8 +1,8 @@
 #ifndef __PARADOX_GSF_H__
 #define __PARADOX_GSF_H__
 
-#define PX_HAVE_GSF 1
-#if PX_HAVE_GSF
+#define PX_HAVE_GSF 
+#if HAVE_GSF
 #include <gsf/gsf-input-stdio.h>
 #include <gsf/gsf-input-memory.h>
 #include <gsf/gsf-output.h>
@@ -12,7 +12,7 @@
 
 #include <paradox.h>
 
-#if PX_HAVE_GSF
+#if HAVE_GSF
 PXLIB_API int PXLIB_CALL
 PX_open_gsf(pxdoc_t *pxdoc, GsfInput *gsf);
 #endif
