@@ -39,10 +39,10 @@ PX_mp_malloc(pxdoc_t *p, size_t size, const char *caller) {
 		fprintf(stderr, "\n");
 	}
 	memlist[i].ptr = a;
-	memlist[i].size = size;
-	summem += size;
+	memlist[i].size = (int)size;
+	summem += (int)size;
 	peakmem = (summem > peakmem) ? summem : peakmem;
-	memlist[i].caller = strdup(caller);
+	memlist[i].caller = strdup(caller);//_strdup(caller);
 	return(a);
 }
 
@@ -55,14 +55,14 @@ PX_mp_realloc(pxdoc_t *p, void *mem, size_t size, const char *caller) {
 		if(memlist[i].ptr == mem) {
 			memlist[i].ptr = a;
 			summem -= memlist[i].size;
-			summem += size;
-			memlist[i].size = size;
+			summem += (int)size;
+			memlist[i].size = (int)size;
 			free(memlist[i].caller);
-			memlist[i].caller = strdup(caller);
+			memlist[i].caller = strdup(caller);//_strdup(caller);
 		}
 	}
 	if(i == MAXMEM) {
-		fprintf(stderr, _("Aiii, did not find memory block at 0x%X to enlarge."), (unsigned int) mem);
+		fprintf(stderr, _("Aiii, did not find memory block at %p to enlarge."), mem);
 		fprintf(stderr, "\n");
 	}
 	return(a);
@@ -76,7 +76,7 @@ PX_mp_free(pxdoc_t *p, void *mem) {
 		i++;
 	}
 	if(i == MAXMEM) {
-		fprintf(stderr, _("Aiii, did not find memory block at 0x%X to free."), (unsigned int) mem);
+		fprintf(stderr, _("Aiii, did not find memory block at %p to free."), mem);
 		fprintf(stderr, "\n");
 	} else {
 		memlist[i].ptr = NULL;
@@ -93,7 +93,7 @@ PX_mp_list_unfreed() {
 	i = j = 0;
 	while(i < MAXMEM) {
 		if(memlist[i].ptr) {
-			fprintf(stderr, _("%d. Memory at address 0x%X (%d) not freed: '%s'."), j, (unsigned int) memlist[i].ptr, memlist[i].size, memlist[i].caller);
+			fprintf(stderr, _("%d. Memory at address %p (%d) not freed: '%s'."), j, memlist[i].ptr, memlist[i].size, memlist[i].caller);
 			fprintf(stderr, "\n");
 			j++;
 		}
